"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SyntaxHighlighter = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _style = require("../../utils/style");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
let highlighterInstance = null;
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await (0, _core.createHighlighterCore)({
      engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
    });
  }
  return highlighterInstance;
}
const SyntaxHighlighter = ({
  text,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = _react.default.useState([]);
  const [loading, setLoading] = _react.default.useState(true);
  const [error, setError] = _react.default.useState(null);

  // Debug theme structure
  _react.default.useEffect(() => {
    console.log('Theme input:', {
      name: theme.name,
      settings: theme.settings?.length,
      colors: theme.colors,
      fg: theme.fg,
      bg: theme.bg
    });
  }, [theme]);

  // Convert theme to RN styles
  const stylesheet = (0, _react.useMemo)(() => {
    const styles = (0, _style.getStylesFromShikiTheme)(theme);
    console.log('Generated stylesheet:', styles);
    return styles;
  }, [theme]);
  _react.default.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);
        const highlighter = await getHighlighter();

        // Load language and theme
        if (typeof language !== 'string') {
          await highlighter.loadLanguage(language);
        }
        await highlighter.loadTheme(theme);

        // Get the theme name from the registration
        const themeName = theme.name || Object.getOwnPropertyDescriptor(theme, 'name')?.value || 'default';
        console.log('Using theme name:', themeName);

        // Highlight the code
        const result = highlighter.codeToTokens(text, {
          lang: typeof language === 'string' ? language : language.name,
          theme: themeName,
          includeExplanation: true // Enable this to get scope information
        });
        console.log('Tokenization result:', {
          lineCount: result.tokens.length,
          firstLineTokens: result.tokens[0]?.map(t => ({
            content: t.content,
            color: t.color,
            scopes: t.explanation?.[0]?.scopes.map(s => s.scopeName)
          }))
        });
        setTokens(result.tokens);
        setError(null);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
        console.error('Highlighting error:', err);
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [text, language, theme]);
  const renderToken = (token, index) => {
    // Get token scope styles
    const scopeStyles = token.explanation?.[0]?.scopes.map(scope => {
      const style = stylesheet[scope.scopeName];
      if (style) {
        console.log('Found style for scope:', scope.scopeName, style);
      }
      return style;
    }).filter(Boolean) || [];
    const style = _reactNative.StyleSheet.flatten([textStyle, {
      fontSize
    }, ...scopeStyles, token.color ? {
      color: token.color
    } : null, token.fontStyle === 1 && {
      fontStyle: 'italic'
    }, token.fontStyle === 2 && {
      fontWeight: 'bold'
    }, token.fontStyle === 4 && {
      textDecorationLine: 'underline'
    }]);
    console.log('Final token style:', {
      content: token.content,
      color: token.color,
      scopeStyles,
      finalStyle: style
    });
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: style,
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [stylesheet.root, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};
exports.SyntaxHighlighter = SyntaxHighlighter;
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map